@@ -1,6 +1,7 @@
 use super::{
     textinput::TextInputComponent, visibility_blocking,
     CommandBlocking, CommandInfo, Component, DrawableComponent,
+    ExternalEditorComponent,
 };
 use crate::{
     get_app_config_path, keys,
@@ -8,23 +9,16 @@ use crate::{
     strings::{self, commands},
     ui::style::SharedTheme,
 };
-use anyhow::{anyhow, Result};
+use anyhow::Result;
 use asyncgit::{
     sync::{self, CommitId, HookResult},
     CWD,
 };
-use crossterm::{
-    event::Event,
-    terminal::{EnterAlternateScreen, LeaveAlternateScreen},
-    ExecutableCommand,
-};
-use scopeguard::defer;
+use crossterm::event::Event;
 use std::{
-    env,
     fs::File,
-    io::{self, Read, Write},
+    io::{Read, Write},
     path::PathBuf,
-    process::Command,
 };
 use tui::{backend::Backend, layout::Rect, Frame};
 
@@ -94,9 +88,9 @@ impl Component for CommitComponent {
                     }
 
                     keys::OPEN_COMMIT_EDITOR => {
-                        self.queue
-                            .borrow_mut()
-                            .push_back(InternalEvent::SuspendPolling);
+                        self.queue.borrow_mut().push_back(
+                            InternalEvent::OpenExternalEditor(None),
+                        );
                         self.hide();
                     }
 
@@ -146,11 +140,11 @@ impl CommitComponent {
 
     pub fn show_editor(&mut self) -> Result<()> {
         const COMMIT_MSG_FILE_NAME: &str = "COMMITMSG_EDITOR";
+        //TODO: use a tmpfile here
         let mut config_path: PathBuf = get_app_config_path()?;
         config_path.push(COMMIT_MSG_FILE_NAME);
 
         {
-            //TODO: use a tmpfile here
             let mut file = File::create(&config_path)?;
             file.write_fmt(format_args!(
                 "{}\n",
@@ -159,33 +153,10 @@ impl CommitComponent {
             file.write_all(strings::COMMIT_EDITOR_MSG.as_bytes())?;
         }
 
-        let mut editor = env::var("GIT_EDTIOR")
-            .ok()
-            .or_else(|| env::var("VISUAL").ok())
-            .or_else(|| env::var("EDITOR").ok())
-            .unwrap_or_else(|| String::from("vi"));
-        editor
-            .push_str(&format!(" {}", config_path.to_string_lossy()));
-
-        let mut editor = editor.split_whitespace();
-
-        let command = editor.next().ok_or_else(|| {
-            anyhow!("unable to read editor command")
-        })?;
-
-        io::stdout().execute(LeaveAlternateScreen)?;
-        defer! {
-            io::stdout().execute(EnterAlternateScreen).expect("reset terminal");
-        }
-
-        Command::new(command)
-            .args(editor)
-            .status()
-            .map_err(|e| anyhow!("\"{}\": {}", command, e))?;
+        ExternalEditorComponent::open_file_in_editor(&config_path)?;
 
         let mut message = String::new();
 
-        //TODO: see above
         let mut file = File::open(&config_path)?;
         file.read_to_string(&mut message)?;
         drop(file);
