@@ -9,7 +9,7 @@ use crate::{
 };
 use anyhow::Result;
 use asyncgit::{
-    sync::{CommitId, Tags},
+    sync::{CommitId, CommitTags},
     AsyncCommitFiles, AsyncNotification,
 };
 use crossbeam_channel::Sender;
@@ -50,25 +50,21 @@ impl CommitDetailsComponent {
         }
     }
 
-    fn get_files_title(&self, loading: bool) -> String {
+    fn get_files_title(&self) -> String {
         let files_count = self.file_tree.file_count();
 
-        if loading {
-            strings::commit::DETAILS_FILES_LOADING_TITLE.to_string()
-        } else {
-            format!(
-                "{} {}",
-                strings::commit::DETAILS_FILES_TITLE,
-                files_count
-            )
-        }
+        format!(
+            "{} {}",
+            strings::commit::DETAILS_FILES_TITLE,
+            files_count
+        )
     }
 
     ///
     pub fn set_commit(
         &mut self,
         id: Option<CommitId>,
-        tags: &Tags,
+        tags: Option<CommitTags>,
     ) -> Result<()> {
         self.details.set_commit(id, tags)?;
 
@@ -78,19 +74,18 @@ impl CommitDetailsComponent {
             {
                 if fetched_id == id {
                     self.file_tree.update(res.as_slice())?;
-                    self.file_tree
-                        .set_title(self.get_files_title(false));
+                    self.file_tree.set_title(self.get_files_title());
 
                     return Ok(());
                 }
             }
+
             self.file_tree.clear()?;
             self.git_commit_files.fetch(id)?;
-            self.file_tree.set_title(self.get_files_title(true));
-        } else {
-            self.file_tree.set_title(self.get_files_title(false));
         }
 
+        self.file_tree.set_title(self.get_files_title());
+
         Ok(())
     }
 
