@@ -9,7 +9,7 @@ use crate::{
 };
 use anyhow::Result;
 use asyncgit::{
-    sync::{CommitId, Tags},
+    sync::{CommitId, CommitTags},
     AsyncDiff, AsyncNotification, DiffParams, DiffType,
 };
 use crossbeam_channel::Sender;
@@ -23,6 +23,7 @@ use tui::{
 
 pub struct InspectCommitComponent {
     commit_id: Option<CommitId>,
+    tags: Option<CommitTags>,
     diff: DiffComponent,
     details: CommitDetailsComponent,
     git_diff: AsyncDiff,
@@ -160,14 +161,20 @@ impl InspectCommitComponent {
             ),
             diff: DiffComponent::new(None, theme),
             commit_id: None,
+            tags: None,
             git_diff: AsyncDiff::new(sender.clone()),
             visible: false,
         }
     }
 
     ///
-    pub fn open(&mut self, id: CommitId) -> Result<()> {
+    pub fn open(
+        &mut self,
+        id: CommitId,
+        tags: Option<CommitTags>,
+    ) -> Result<()> {
         self.commit_id = Some(id);
+        self.tags = tags;
         self.show()?;
 
         Ok(())
@@ -215,17 +222,19 @@ impl InspectCommitComponent {
                     }
 
                     self.git_diff.request(diff_params)?;
+                    self.diff.clear(true)?;
+                    return Ok(());
                 }
             }
 
-            self.diff.clear()?;
+            self.diff.clear(false)?;
         }
 
         Ok(())
     }
 
     fn update(&mut self) -> Result<()> {
-        self.details.set_commit(self.commit_id, &Tags::new())?;
+        self.details.set_commit(self.commit_id, self.tags.clone())?;
         self.update_diff()?;
 
         Ok(())
