@@ -2,29 +2,32 @@ use super::{
     visibility_blocking, CommandBlocking, CommandInfo, Component,
     DrawableComponent,
 };
-use crate::{keys, strings, ui};
+use crate::{
+    keys,
+    strings::{self, commands},
+    ui,
+};
 use crossterm::event::Event;
 use std::borrow::Cow;
-use strings::commands;
 use tui::{
     backend::Backend,
     layout::{Alignment, Rect},
-    widgets::{Block, Borders, Clear, Paragraph, Text},
+    widgets::{Block, BorderType, Borders, Clear, Paragraph, Text},
     Frame,
 };
-use ui::style::Theme;
+use ui::style::SharedTheme;
 
 pub struct MsgComponent {
     msg: String,
     visible: bool,
-    theme: Theme,
+    theme: SharedTheme,
 }
 
 use anyhow::Result;
 
 impl DrawableComponent for MsgComponent {
     fn draw<B: Backend>(
-        &mut self,
+        &self,
         f: &mut Frame<B>,
         _rect: Rect,
     ) -> Result<()> {
@@ -41,7 +44,8 @@ impl DrawableComponent for MsgComponent {
                     Block::default()
                         .title(strings::MSG_TITLE_ERROR)
                         .title_style(self.theme.text_danger())
-                        .borders(Borders::ALL),
+                        .borders(Borders::ALL)
+                        .border_type(BorderType::Thick),
                 )
                 .alignment(Alignment::Left)
                 .wrap(true),
@@ -96,11 +100,11 @@ impl Component for MsgComponent {
 }
 
 impl MsgComponent {
-    pub fn new(theme: &Theme) -> Self {
+    pub const fn new(theme: SharedTheme) -> Self {
         Self {
             msg: String::new(),
             visible: false,
-            theme: *theme,
+            theme,
         }
     }
     ///
