@@ -58,9 +58,26 @@ impl StatusTree {
 
         self.update_visibility(None, 0, true);
 
+        //NOTE: now that visibility is set we can make sure selection is visible
+        if let Some(idx) = self.selection {
+            self.selection = Some(self.find_visible_idx(idx));
+        }
+
         Ok(())
     }
 
+    fn find_visible_idx(&self, mut idx: usize) -> usize {
+        while idx > 0 {
+            if self.is_visible_index(idx) {
+                break;
+            }
+
+            idx -= 1;
+        }
+
+        idx
+    }
+
     ///
     pub fn move_selection(&mut self, dir: MoveSelection) -> bool {
         if let Some(selection) = self.selection {
@@ -199,11 +216,20 @@ impl StatusTree {
         let item_path =
             self.tree[current_selection].info.full_path.clone();
 
-        if matches!(item_kind,  FileTreeItemKind::Path(PathCollapsed(collapsed))
-        if collapsed)
-        {
-            self.expand(&item_path, current_selection);
-            return SelectionChange::new(current_selection, true);
+        match item_kind {
+            FileTreeItemKind::Path(PathCollapsed(collapsed))
+                if collapsed =>
+            {
+                self.expand(&item_path, current_selection);
+                return SelectionChange::new(current_selection, true);
+            }
+            FileTreeItemKind::Path(PathCollapsed(collapsed))
+                if !collapsed =>
+            {
+                return self
+                    .selection_updown(current_selection, false);
+            }
+            _ => (),
         }
 
         SelectionChange::new(current_selection, false)
@@ -306,8 +332,8 @@ impl StatusTree {
                 inner_collapsed = Some(format!("{}/", &item_path));
             }
 
-            if prefix.is_none()
-                || item_path.starts_with(prefix.unwrap())
+            if prefix
+                .map_or(true, |prefix| item_path.starts_with(prefix))
             {
                 self.tree[i].info.visible = true
             } else {
@@ -385,6 +411,30 @@ mod tests {
         assert_eq!(res.selection, Some(1));
     }
 
+    #[test]
+    fn test_keep_selected_index_if_not_collapsed() {
+        let mut res = StatusTree::default();
+        res.update(&string_vec_to_status(&["a/b", "c"])).unwrap();
+
+        res.collapse("a/b", 0);
+
+        res.selection = Some(2);
+
+        res.update(&string_vec_to_status(&["a/b"])).unwrap();
+        assert_eq!(
+            get_visibles(&res),
+            vec![
+                true,  //
+                false, //
+            ]
+        );
+        assert_eq!(
+            res.is_visible_index(res.selection.unwrap()),
+            true
+        );
+        assert_eq!(res.selection, Some(0));
+    }
+
     #[test]
     fn test_keep_collapsed_states() {
         let mut res = StatusTree::default();
