@@ -2,7 +2,7 @@
 #![deny(clippy::cargo)]
 #![deny(clippy::pedantic)]
 #![deny(clippy::nursery)]
-#![deny(clippy::result_unwrap_used)]
+#![deny(clippy::unwrap_used)]
 #![deny(clippy::panic)]
 #![allow(clippy::module_name_repetitions)]
 #![allow(clippy::multiple_crate_versions)]
@@ -79,8 +79,11 @@ fn main() -> Result<()> {
         return Ok(());
     }
 
-    // TODO: To be removed in a future version, when upgrading from 0.6.x or earlier is unlikely
-    migrate_config()?;
+    // TODO: Remove this when upgrading from v0.8.x is unlikely
+    // Only run this migration on macOS, as it's the only platform where the config needs to be moved
+    if cfg!(target_os = "macos") {
+        migrate_config()?;
+    }
 
     setup_terminal()?;
     defer! {
@@ -136,7 +139,12 @@ fn main() -> Result<()> {
                     app.event(ev)?
                 }
                 QueueEvent::Tick => app.update()?,
-                QueueEvent::GitEvent(ev) => app.update_git(ev)?,
+                QueueEvent::GitEvent(ev)
+                    if ev != AsyncNotification::FinishUnchanged =>
+                {
+                    app.update_git(ev)?
+                }
+                QueueEvent::GitEvent(..) => (),
                 QueueEvent::SpinnerUpdate => unreachable!(),
             }
 
@@ -224,23 +232,6 @@ fn start_terminal<W: Write>(
     Ok(terminal)
 }
 
-fn migrate_config() -> Result<()> {
-    let cache_path: PathBuf = get_app_cache_path()?;
-
-    let entries = cache_path.read_dir()?.flatten().filter(|entry| {
-        !entry.file_name().to_string_lossy().ends_with(".log")
-    });
-
-    let config_path: PathBuf = get_app_config_path()?;
-    for entry in entries {
-        let mut config_path: PathBuf = config_path.clone();
-        config_path.push(entry.file_name());
-        fs::rename(entry.path(), config_path)?;
-    }
-
-    Ok(())
-}
-
 fn get_app_cache_path() -> Result<PathBuf> {
     let mut path = dirs::cache_dir()
         .ok_or_else(|| anyhow!("failed to find os cache dir."))?;
@@ -259,6 +250,29 @@ fn get_app_config_path() -> Result<PathBuf> {
     Ok(path)
 }
 
+fn migrate_config() -> Result<()> {
+    let mut path = dirs::preference_dir().ok_or_else(|| {
+        anyhow!("failed to find os preference dir.")
+    })?;
+
+    path.push("gitui");
+    if !path.exists() {
+        return Ok(());
+    }
+
+    let config_path = get_app_config_path()?;
+    let entries = path.read_dir()?.flatten();
+    for entry in entries {
+        let mut config_path = config_path.clone();
+        config_path.push(entry.file_name());
+        fs::rename(entry.path(), config_path)?;
+    }
+
+    let _ = fs::remove_dir(path);
+
+    Ok(())
+}
+
 fn setup_logging() -> Result<()> {
     let mut path = get_app_cache_path()?;
     path.push("gitui.log");
