@@ -13,10 +13,12 @@ use anyhow::Result;
 use asyncgit::{
     cached,
     sync::{self, CommitId},
-    AsyncLog, AsyncNotification, FetchStatus, CWD,
+    AsyncLog, AsyncNotification, AsyncTags, FetchStatus, CWD,
 };
 use crossbeam_channel::Sender;
 use crossterm::event::Event;
+use std::time::Duration;
+use sync::CommitTags;
 use tui::{
     backend::Backend,
     layout::{Constraint, Direction, Layout, Rect},
@@ -30,6 +32,7 @@ pub struct Revlog {
     commit_details: CommitDetailsComponent,
     list: CommitList,
     git_log: AsyncLog,
+    git_tags: AsyncTags,
     queue: Queue,
     visible: bool,
     branch_name: cached::BranchName,
@@ -51,6 +54,7 @@ impl Revlog {
             ),
             list: CommitList::new(strings::LOG_TITLE, theme),
             git_log: AsyncLog::new(sender),
+            git_tags: AsyncTags::new(sender),
             visible: false,
             branch_name: cached::BranchName::new(CWD),
         }
@@ -59,6 +63,7 @@ impl Revlog {
     ///
     pub fn any_work_pending(&self) -> bool {
         self.git_log.is_pending()
+            || self.git_tags.is_pending()
             || self.commit_details.any_work_pending()
     }
 
@@ -78,19 +83,17 @@ impl Revlog {
                 self.fetch_commits()?;
             }
 
-            if !self.list.has_tags() || log_changed {
-                self.list.set_tags(sync::get_tags(CWD)?);
-            }
+            self.git_tags.request(Duration::from_secs(3), false)?;
 
             self.list.set_branch(
                 self.branch_name.lookup().map(Some).unwrap_or(None),
             );
 
             if self.commit_details.is_visible() {
-                self.commit_details.set_commit(
-                    self.selected_commit(),
-                    self.list.tags().expect("tags"),
-                )?;
+                let commit = self.selected_commit();
+                let tags = self.selected_commit_tags(&commit);
+
+                self.commit_details.set_commit(commit, tags)?;
             }
         }
 
@@ -106,6 +109,12 @@ impl Revlog {
             match ev {
                 AsyncNotification::CommitFiles
                 | AsyncNotification::Log => self.update()?,
+                AsyncNotification::Tags => {
+                    if let Some(tags) = self.git_tags.last()? {
+                        self.list.set_tags(tags);
+                        self.update()?;
+                    }
+                }
                 _ => (),
             }
         }
@@ -133,6 +142,25 @@ impl Revlog {
     fn selected_commit(&self) -> Option<CommitId> {
         self.list.selected_entry().map(|e| e.id)
     }
+
+    fn selected_commit_tags(
+        &self,
+        commit: &Option<CommitId>,
+    ) -> Option<CommitTags> {
+        let tags = self.list.tags();
+
+        commit.and_then(|commit| {
+            if let Some(tags) = tags {
+                if let Some(tags) = tags.get(&commit) {
+                    Some(tags.clone())
+                } else {
+                    None
+                }
+            } else {
+                None
+            }
+        })
+    }
 }
 
 impl DrawableComponent for Revlog {
@@ -171,19 +199,49 @@ impl Component for Revlog {
             if event_used {
                 self.update()?;
                 return Ok(true);
-            } else if let Event::Key(keys::LOG_COMMIT_DETAILS) = ev {
-                self.commit_details.toggle_visible()?;
-                self.update()?;
-                return Ok(true);
-            } else if let Event::Key(keys::FOCUS_RIGHT) = ev {
-                return if let Some(id) = self.selected_commit() {
-                    self.queue
-                        .borrow_mut()
-                        .push_back(InternalEvent::InspectCommit(id));
-                    Ok(true)
-                } else {
-                    Ok(false)
-                };
+            } else {
+                match ev {
+                    Event::Key(keys::LOG_COMMIT_DETAILS) => {
+                        self.commit_details.toggle_visible()?;
+                        self.update()?;
+                        return Ok(true);
+                    }
+
+                    Event::Key(keys::LOG_TAG_COMMIT) => {
+                        return if let Some(id) =
+                            self.selected_commit()
+                        {
+                            self.queue.borrow_mut().push_back(
+                                InternalEvent::TagCommit(id),
+                            );
+                            Ok(true)
+                        } else {
+                            Ok(false)
+                        };
+                    }
+
+                    Event::Key(keys::FOCUS_RIGHT)
+                        if self.commit_details.is_visible() =>
+                    {
+                        return if let Some(id) =
+                            self.selected_commit()
+                        {
+                            self.queue.borrow_mut().push_back(
+                                InternalEvent::InspectCommit(
+                                    id,
+                                    self.selected_commit_tags(&Some(
+                                        id,
+                                    )),
+                                ),
+                            );
+                            Ok(true)
+                        } else {
+                            Ok(false)
+                        };
+                    }
+
+                    _ => (),
+                }
             }
         }
 
@@ -212,6 +270,12 @@ impl Component for Revlog {
                 || force_all,
         ));
 
+        out.push(CommandInfo::new(
+            commands::LOG_TAG_COMMIT,
+            true,
+            self.visible || force_all,
+        ));
+
         visibility_blocking(self)
     }
 
