@@ -57,6 +57,21 @@ pub fn centered_rect(
         .split(popup_layout[1])[1]
 }
 
+/// makes sure Rect `r` at least stays as big as `width`/`height`
+pub fn rect_min(width: u16, height: u16, r: Rect) -> Rect {
+    let new_width = r.width.max(width);
+    let new_height = r.height.max(height);
+    let diff_width = new_width.saturating_sub(r.width);
+    let diff_height = new_height.saturating_sub(r.height);
+
+    Rect::new(
+        r.x.saturating_sub(diff_width / 2),
+        r.y.saturating_sub(diff_height / 2),
+        new_width,
+        new_height,
+    )
+}
+
 pub fn centered_rect_absolute(
     width: u16,
     height: u16,
